# Welcome to the vLLM Spyre Plugin

:::
<p style="text-align:center">
<script async defer src="https://buttons.github.io/buttons.js"></script>
<a class="github-button" href="https://github.com/vllm-project/vllm-spyre" data-show-count="true" data-size="large" aria-label="Star">Star</a>
<a class="github-button" href="https://github.com/vllm-project/vllm-spyre/subscription" data-icon="octicon-eye" data-size="large" aria-label="Watch">Watch</a>
<a class="github-button" href="https://github.com/vllm-project/vllm-spyre/fork" data-icon="octicon-repo-forked" data-size="large" aria-label="Fork">Fork</a>
</p>
:::

The vLLM Spyre plugin (`vllm-spyre`) is a dedicated backend extension that enables seamless integration of IBM Spyre Accelerator with vLLM. It follows the architecture described in [vLLM's Plugin System](https://docs.vllm.ai/en/latest/design/plugin_system.html), making it easy to integrate IBM's advanced AI acceleration into existing vLLM workflows.

## Documentation

:::{toctree}
:caption: Getting Started
:maxdepth: 1
installation
:::

:::{toctree}
:caption: User Guide
:maxdepth: 1
user_guide/configuration
user_guide/env_vars
user_guide/supported_features
user_guide/supported_models
:::

:::{toctree}
:caption: Developer Guide
:maxdepth: 2
contributing/overview
:::
